/*
Copyright 2024, Savanni D'Gerinel <savanni@luminescent-dreams.com>

This file is part of On the Grid.

On the Grid is free software: you can redistribute it and/or modify it under the terms of the GNU
General Public License as published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

On the Grid is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License along with On the Grid. If not, see <https://www.gnu.org/licenses/>.
*/

use crate::Core;
use serde::{Deserialize, Serialize};
use sgf::GameRecord;

#[derive(Clone, Debug, Serialize, Deserialize)]
pub enum LibraryRequest {
    ListGames,
}

#[derive(Clone, Debug)]
pub enum LibraryResponse {
    Games(Vec<GameRecord>),
}

async fn handle_list_games(model: &Core) -> LibraryResponse {
    let library = model.library();
    match *library {
        Some(ref library) => {
            let info = library.all_games().cloned().collect::<Vec<GameRecord>>();
            LibraryResponse::Games(info)
        }
        None => LibraryResponse::Games(vec![]),
    }
}

pub async fn handle(model: &Core, request: LibraryRequest) -> LibraryResponse {
    match request {
        LibraryRequest::ListGames => handle_list_games(model).await,
    }
}
